SQLObject 3.9.1
===============

Thanks for looking at SQLObject.  SQLObject is an object-relational
mapper, i.e., a library that will wrap your database tables in Python
classes, and your rows in Python instances.

It currently supports MySQL, PostgreSQL and SQLite; connections to other
backends - Firebird, Sybase, MSSQL and MaxDB (also known as SAPDB) - are
lesser debugged).

Python 2.7 or 3.4+ is required.

For more information please see the documentation in
`<docs/SQLObject.rst>`_, or online at http://sqlobject.org/
